==> realestate-supervise-common-1.1.0-20220818.055648-18-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcq1Ls.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.encrypt;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description QLT_FW_FDCQ_DZ 房地产权（项目内多幢房屋）属性结构
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcq1_ls"
)
public class BaFdcq1Ls implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String fdzl;

    @XmlAttribute
    @encrypt
    private String tdsyqr;

    @XmlAttribute
    @Nullable
    private String dytdmj;

    @XmlAttribute
    @Nullable
    private String fttdmj;

    @XmlAttribute
    private Date tdsyqssj;

    @XmlAttribute
    private Date tdsyjssj;

    @XmlAttribute
    @Nullable
    private String fdcjyjg;

    @XmlAttribute
    @Nullable
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    @Nullable
    private String fcfht;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String tdsyqx;

    @XmlAttribute
    private String jedw;

    @XmlAttribute
    private String yt;

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getTdsyqx() {
        return tdsyqx;
    }

    public void setTdsyqx(String tdsyqx) {
        this.tdsyqx = tdsyqx;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getFdzl() {
        return fdzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public String getDytdmj() {
        return dytdmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public String getFdcjyjg() {
        return fdcjyjg;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setFdzl(String fdzl) {
        this.fdzl = fdzl;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public void setDytdmj(String dytdmj) {
        this.dytdmj = dytdmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public void setFdcjyjg(String fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getFcfht() {
        return fcfht;
    }

    public void setFcfht(String fcfht) {
        this.fcfht = fcfht;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }
}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcq1Ls.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description QLT_FW_FDCQ_DZ 房地产权（项目内多幢房屋）属性结构
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcq1_ls"
)
public class BaFdcq1Ls implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String fdzl;

    @XmlAttribute
    @encrypt
    private String tdsyqr;

    @XmlAttribute
    @Nullable
    private String dytdmj;

    @XmlAttribute
    @Nullable
    private String fttdmj;

    @XmlAttribute
    private Date tdsyqssj;

    @XmlAttribute
    private Date tdsyjssj;

    @XmlAttribute
    @Nullable
    private String fdcjyjg;

    @XmlAttribute
    @Nullable
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    @Nullable
    private String fcfht;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String tdsyqx;

    @XmlAttribute
    private String jedw;

    @XmlAttribute
    private String yt;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getTdsyqx() {
        return tdsyqx;
    }

    public void setTdsyqx(String tdsyqx) {
        this.tdsyqx = tdsyqx;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getFdzl() {
        return fdzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public String getDytdmj() {
        return dytdmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public String getFdcjyjg() {
        return fdcjyjg;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setFdzl(String fdzl) {
        this.fdzl = fdzl;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public void setDytdmj(String dytdmj) {
        this.dytdmj = dytdmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public void setFdcjyjg(String fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getFcfht() {
        return fcfht;
    }

    public void setFcfht(String fcfht) {
        this.fcfht = fcfht;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }
}
